library(fields)


## Set the working directory in R to the reproduce folder before executing the following R-code

path_fig="figures/"

n<-200
T<-1
Id<-diag(rep(1,n*T))
one<-matrix(rep(1,n*T),n*T,1)



######################
###fig S.2.1

set.seed(1)
xcoord<-sample(seq(0,1, by=0.001),n,replace=F)
ycoord<-sample(seq(0,1, by=0.001),n,replace=F)
coord<-cbind(xcoord,ycoord)

plot(xcoord,ycoord,,xlab="",ylab="", cex.axis=2.5)
dev.copy2pdf(file=paste(path_fig,"200uniform.pdf",sep=""),width=8,height=8)

####################
##fig S.2.4


source<-c(0.9361968,0.1165034)


phi.x.s<--sqrt(2)*log(0.05)
#compute x(s) for each site.
x<-c()
for (i in 1:n){
x[i]<-exp(-phi.x.s*sqrt((xcoord[i]-source[1])^2+(ycoord[i]-source[2])^2))
}
           
x.std<-(x-mean(x))/sd(x)

library(viridis)
surface(Tps(coord,x.std),xlab="",ylab="",cex.axis=2.,extrap=TRUE, col =  viridis(12))
points(source[1],source[2],pch=19,cex=1.75)
points(xcoord,ycoord, pch= "+", cex=1.25)
dev.copy2pdf(file=paste(path_fig,"unixsurfacebeta1.pdf",sep=""),width=6,height=6)


#################   redo in ggplot    ############
library(akima)
library(ggplot2)
library(tidyr)
library(viridis)

coord.df<-data.frame(x=xcoord, y=ycoord)
source.df<-data.frame(x=source[1], y=source[2])


res=0.01

xo=seq(0.0,1,res)
yo=seq(0,1,res)


interp<-interp(x=coord[,1],y=coord[,2],z=x.std, xo=xo, yo=yo, linear=FALSE, extrap=TRUE)

interp1<-data.frame(x = interp$x, interp$z )
names(interp1)[1:length(interp$y)+1] <- interp$y
interp1 <- gather(interp1,key = y,value = x.std,-x,convert = TRUE)

#overide, assource df not plotting correctly
row<-interp1[which(interp1$x.std == max(interp1$x.std)),]
#source.df<-data.frame(x=row$x, y=row$y)


P<-ggplot()+
   geom_raster(data=interp1, aes(x = x, y = y,fill = x.std)) + 
   stat_contour(data=interp1,aes(x = x, y = y,z = x.std), colour = "black", binwidth = 0.6) +
   scale_fill_gradientn(colours = viridis(12), limits = c(-1,5), guide = "colourbar")+
   geom_point(data = coord.df, aes(x=x,y=y), shape = "+", size = 6)+
   geom_point(data = source.df, aes(x=x,y=y), size = 5) 

P <-P +  theme(  legend.title=element_text(size=13),
                    legend.text=element_text(size=13),
                    strip.text.x = element_blank(), #strip out facet grid labels
                    strip.text.y = element_blank(),
                    strip.background = element_blank(),
                    axis.line=element_blank(),
                   # axis.text.x=element_blank(),
                   # axis.text.y=element_blank(),
                    axis.text=element_text(size = 16),
                   # axis.ticks=element_blank(),
                    axis.title.x=element_blank(),
                    axis.title.y=element_blank(),
                   # legend.position="none",
                   # panel.background=element_blank(),
                   # panel.border=element_blank(),
                    panel.grid.major=element_blank(),
                    panel.grid.minor=element_blank(),
                   # plot.background=element_blank()
                  )
P

dev.copy2pdf(file=paste(path_fig,"unixsurfacebeta1GG.pdf",sep=""),width=7,height=6)


##################################
##fig S.2.5


dist<-matrix(rep(NA,n*n),n,n)
for(i in 1:n){
for(j in 1:n){
dist[i,j]=sqrt((xcoord[i]-xcoord[j])^2+(ycoord[i]-ycoord[j])^2)
}}


sigma.sq<-c(100,10,1,0.1,0.01)
sigma.sq.w=1

D<-diag(x.std)

ds<-c(sqrt(2)/3,2*sqrt(2)/3,sqrt(2))
all_weights<-array(NA,dim=c(length(ds),n,length(sigma.sq)))


for(j in 1:length(ds)){
phi.w.s<-(-log(0.05)/ds[j])
if (phi.w.s==Inf)
Sigma.w<-sigma.sq.w*Id
if (phi.w.s!=Inf)
Sigma.w<-sigma.sq.w*exp(-phi.w.s*dist)
C2X1<-Sigma.w%*%D

for(i in 1:length(sigma.sq)){
W<-C2X1%*%(solve((sigma.sq[i]*Id)+(D%*%C2X1))%*%D)#Woodbury representation
weights<-W%*%one
all_weights[j,,i]<-weights
}
}


cex.main=2.5
cex.lab=2.
cex.axis=1.25


par(mfrow=c(5,3),mar=c(1, 4, 1, 2),oma=c(1,1,1,1) )#b,l,t,r

surface(Tps(coord,all_weights[1,,1]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[2,,1]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[3,,1]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))


surface(Tps(coord,all_weights[1,,2]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[2,,2]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[3,,2]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))


surface(Tps(coord,all_weights[1,,3]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[2,,3]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[3,,3]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))


surface(Tps(coord,all_weights[1,,4]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[2,,4]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[3,,4]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))



surface(Tps(coord,all_weights[1,,5]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[2,,5]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))
surface(Tps(coord,all_weights[3,,5]),xlab="",ylab="",cex.main=cex.main,cex.lab=cex.lab,cex.axis=cex.axis,
zlim=c(0,1.01),extrap=TRUE,main="", col =  viridis(12))

#dev.copy2pdf(file="WeightsSurface200beta1.pdf",width=6,height=6)
dev.copy2pdf(file=paste(path_fig,"WeightsSurface200beta1.pdf",sep=""),width=6,height=6)


############################# recreate plot with ggplot2 #############################




library(ggplot2)
library(akima)
library(viridis)
library(tidyr)

res=0.01

xo=seq(0,1,res)
yo=seq(0,1,res)


k=0
for(i in 1:5){
for(j in 1:3){

weights<-all_weights[j,,i]
interp<-interp(x=coord[,1],y=coord[,2],z=weights, xo=xo, yo=yo, linear=FALSE, extrap=TRUE)

interp$z <- replace(interp$z, interp$z > 1, 1) #cap interpolations

k<-k+1

assign(paste("interp",k,sep=""),data.frame(x = interp$x, interp$z ))
tmp<-get(paste("interp",k,sep=""))
names(tmp)[1:length(interp$y)+1] <- interp$y
tmp <- gather(tmp,key = y,value = weights,-x,convert = TRUE)
assign(paste("interp",k,sep=""),tmp)

#interp1<-data.frame(x = interp$x, interp$z )
#names(interp1)[1:length(interp$y)+1] <- interp$y
#interp1 <- gather(interp1,key = y,value = weights,-x,convert = TRUE)
}}

interp1$r<-"1"; interp2$r<-"1";interp3$r<-"1";
interp4$r<-"2"; interp5$r<-"2";interp6$r<-"2";
interp7$r<-"3"; interp8$r<-"3";interp9$r<-"3";
interp10$r<-"4"; interp11$r<-"4";interp12$r<-"4";
interp13$r<-"5"; interp14$r<-"5";interp15$r<-"5";

interp1$d<-"1"; interp2$d<-"2"; interp3$d<-"3"
interp4$d<-"1"; interp5$d<-"2"; interp6$d<-"3"
interp7$d<-"1"; interp8$d<-"2"; interp9$d<-"3"
interp10$d<-"1"; interp11$d<-"2"; interp12$d<-"3"
interp13$d<-"1"; interp14$d<-"2"; interp15$d<-"3"


B<-data.frame(rbind(interp1,interp2, interp3, 
                    interp4,interp5, interp6,
                    interp7, interp8, interp9,
                    interp10,interp11,interp12,
                    interp13,interp14,interp15))

P<-ggplot(B, aes(x = x, y = y,fill = weights))+   geom_raster() +
             #geom_point(df, aes(x=x,))
             geom_contour(aes(z = weights), colour = "black", binwidth = 0.1) +
             scale_fill_gradientn(colours = viridis(12),
                       limits = c(0,1.),
                       guide = "colourbar")+
             facet_grid(r~d)+
            theme(  legend.title=element_text(size=13),
                    legend.text=element_text(size=13),
                    strip.text.x = element_blank(), #strip out facet grid labels
                    strip.text.y = element_blank(),
                    strip.background = element_blank(),
                    axis.line=element_blank(),
                    axis.text.x=element_blank(),
                    axis.text.y=element_blank(),
                    axis.ticks=element_blank(),
                    axis.title.x=element_blank(),
                    axis.title.y=element_blank(),
                 #   legend.position="none",
                    panel.background=element_blank(),
                    panel.border=element_blank(),
                    panel.grid.major=element_blank(),
                    panel.grid.minor=element_blank(),
                    plot.background=element_blank()
                  ) # + 
            #scale_y_continuous(breaks=c(0,1)) #determine tick placement. comment out axis.text axis.tick 
            #scale_y_continuous(breaks=c(0,1)) #
P
dev.copy2pdf(file=paste(path_fig,"WeightsSurface200beta1GG.pdf",sep=""),width=8,height=6)







